Coverage for tests/test_integer_literal_has_correct_kind.py: 100%

1# pylint: disable=W0621,C0116,C0114

2 import pytest

3

4 from castep_linter import tests

5 from castep_linter.fortran.parser import get_fortran_parser

6 from castep_linter.scan_files import run_tests_on_code

7

8

9@pytest.fixture

10 def test_list():

11 return {"number_literal": [tests.test_number_literal]}

12

13

14@pytest.fixture

15 def parser():

16 return get_fortran_parser()

17

18

19 def test_integer_literal_no_dp(parser, test_list):

20 code = b"z = 1"

21 error_log = run_tests_on_code(parser, code, test_list, "filename")

22 assert len(error_log.errors) == 0

23

24

25 def test_integer_literal_has_dp(parser, test_list):

26 code = b"z = 1_dp"

27 error_log = run_tests_on_code(parser, code, test_list, "filename")

28 assert len(error_log.errors) == 1